export const deg360 = (n) => (n < 0) ? 360 + n : n,
	getAngleXZ = (a, b) => Math.atan2((b.z - a.z), (b.x - a.x)) * 180 / Math.PI,
	angleDif = (a, b) => (b - a < 0) ? (b - a) + 360 : ((b - a > 180) ? (b - a) - 360 : b - a),
	distXZ = (a, b) => Math.sqrt(Math.pow(b.x - a.x, 2) + Math.pow(b.z - a.z, 2));

export function addItem(e, item) {
    if (!e || !e.getComponent('inventory')) return;
    e.getComponent('inventory').container.addItem(item);
}
export function addItemToSlot(e, slot, n) {
    if (!e || !e.getComponent('inventory')) return;
    let s = isNaN(n) ? e.selectedSlot : slot;
    let v = isNaN(n) ? slot : n;
    let item = getItem(e, s);
    item.amount += v;
    setItem(e, item, s);
}
export function getItem(e, slot) {
    if (!e || !e.getComponent('inventory')) return;
    let s = isNaN(slot) ? e.selectedSlot : slot;
    if (e.getComponent('inventory').container.getItem(s)) return e.getComponent('inventory').container.getItem(s);
    return;
}
export function setItem(e, item, slot) {
    if (!e || !e.getComponent('inventory')) return;
    if (isNaN(slot)) e.getComponent('inventory').container.setItem(e.selectedSlot, item);
    else e.getComponent('inventory').container.setItem(slot, item);
}
export function lookForItem(e, id) {
    if (!e || !e.getComponent('inventory')) return;
    let c = e.getComponent('inventory').container;
    for (let i = 0; i < c.size; i++) {
        if (c.getItem(i) && c.getItem(i).typeId.startsWith(id)) return { item: c.getItem(i), slot: i };
    }
    return;
}
export function clearItem(e, slot) {
    if (!e || !e.getComponent('inventory')) return;
    let s = isNaN(slot) ? e.selectedSlot : slot;
    e.getComponent('inventory').container.clearItem(s);
}
export function storeDataToEntity(e, n, v) {
    if (!e) return;
    for (let t of e.getTags()) {
        if (t.startsWith(`${n}=`)) e.removeTag(t);
    }
    e.addTag(`${n}=${v}`);
}
export function appendDataToEntity(e, n, v) {
	if (!e) return;
	let c = 0;
	for (let t of e.getTags()) {
		if (t.startsWith(`${n}`)) c++;
	}
	e.addTag(`${n}${c == 0 ? '' : c}=${v}`);
}
export function getDataFromEntity(e, n) {
    if (!e) return;
    for (let t of e.getTags()) {
        if (t.startsWith(n)) {
			let val = t.split('=')[1];
			try {
				return JSON.parse(val);
			} catch (_) {
				if (!isNaN(val)) return parseFloat(val);
				else if (val.toLowerCase() === 'true') return true;
				else if (val.toLowerCase() === 'false') return false;
				return val;
            }
        }
    }
    return null;
}
export function removeDataFromEntity(e, n) {
    if (!e) return;
    for (let t of e.getTags()) {
        if (t.startsWith(`${n}=`)) e.removeTag(t);
    }
}
export function getAllDataNamesFromEntity(e) {
	if (!e) return;
	let list = [];
	for (let t of e.getTags()) {
		if (t.indexOf('=') >= 0) list.push(t.split('=')[0]);
	}
	return list;
}
export function entityHasData(e, n) {
	if (!e) return;
	for (let t of e.getTags()) {
		if (t.startsWith(`${n}=`)) return true;
	}
	return false;
}
export function getBlockPermutationValue(block, name) {
    if (block.typeId == 'minecraft:air') return;
    let p = block.permutation.getAllProperties();
    if (!p) return;
    for (let i in p) {
        if (p[i].name == name) return p[i].value;
    }
    return;
}
export function capFirstLetter(str) {
	return str.charAt(0).toUpperCase() + str.slice(1);
}

export const effects = [
	'speed',
	'slowness',
	'haste',
	'mining_fatigue',
	'strength',
	'jump_boost',
	'nausea',
	'regeneration',
	'resistance',
	'fire_resistance',
	'water_breathing',
	'invisibility',
	'blindness',
	'night_vision',
	'hunger',
	'weakness',
	'poison',
	'wither',
	'health_boost',
	'absorption',
	'levitation',
	'conduit_power',
	'slow_falling',
	'bad_omen',
	'village_hero',
	'darkness'
], armor = [
	[
		{ 'turtle_helmet': 2 },
		{ 'leather_helmet': 1 },
		{ 'golden_helmet': 2 },
		{ 'chainmail_helmet': 2 },
		{ 'iron_helmet': 2 },
		{ 'diamond_helmet': 3 },
		{ 'netherite_helmet': 3 }
	],
	[
		{ 'leather_chestplate': 3 },
		{ 'golden_chestplate': 5 },
		{ 'chainmail_chestplate': 5 },
		{ 'iron_chestplate': 6 },
		{ 'diamond_chestplate': 8 },
		{ 'netherite_chestplate': 8 },

		{ 'leather_horse_armor': 3 },
		{ 'iron_horse_armor': 5 },
		{ 'golden_horse_armor': 7 },
		{ 'diamond_horse_armor': 11 }
	],
	[
		{ 'leather_leggings': 2 },
		{ 'golden_leggings': 3 },
		{ 'chainmail_leggings': 4 },
		{ 'iron_leggings': 5 },
		{ 'diamond_leggings': 6 },
		{ 'netherite_leggings': 6 }
	],
	[
		{ 'leather_boots': 1 },
		{ 'golden_boots': 1 },
		{ 'chainmail_boots': 1 },
		{ 'iron_boots': 2 },
		{ 'diamond_boots': 3 },
		{ 'netherite_boots': 3 }
	]
], damage_list = {
	'minecraft:player': {
		'default': [1, 1, 1],
		'items': {
			'minecraft:wooden_sword': 5,
			'minecraft:stone_sword': 6,
			'minecraft:iron_sword': 7,
			'minecraft:diamond_sword': 8,
			'minecraft:golden_sword': 5,
			'minecraft:netherite_sword': 9,
			'minecraft:trident': 9,
			'minecraft:wooden_shovel': 2,
			'minecraft:stone_shovel': 3,
			'minecraft:iron_shovel': 4,
			'minecraft:diamond_shovel': 5,
			'minecraft:golden_shovel': 2,
			'minecraft:netherite_shovel': 6,
			'minecraft:wooden_pickaxe': 3,
			'minecraft:stone_pickaxe': 4,
			'minecraft:iron_pickaxe': 5,
			'minecraft:diamond_pickaxe': 6,
			'minecraft:golden_pickaxe': 3,
			'minecraft:netherite_pickaxe': 7,
			'minecraft:wooden_axe': 4,
			'minecraft:stone_axe': 5,
			'minecraft:iron_axe': 6,
			'minecraft:diamond_axe': 7,
			'minecraft:golden_axe': 4,
			'minecraft:netherite_axe': 8,
			'minecraft:wooden_hoe': 3,
			'minecraft:stone_hoe': 4,
			'minecraft:iron_hoe': 5,
			'minecraft:diamond_hoe': 6,
			'minecraft:golden_hoe': 3,
			'minecraft:netherite_hoe': 7
		}
	},
	'minecraft:wolf': {
		'default': [2, 3, 4],
		'items': {}
	},
	'minecraft:creeper': {
		'default': [22, 43, 64],
		'items': {}
	},
	'minecraft:charged_creeper': {
		'default': [43, 85, 127],
		'items': {}
	},
	'minecraft:polar_bear': {
		'default': [4, 6, 9],
		'items': {}
	},
	'minecraft:llama': {
		'default': [1, 1, 1],
		'items': {}
	},
	'minecraft:trader_llama': {
		'default': [1, 1, 1],
		'items': {}
	},
	'minecraft:pufferfish': {
		'default': [1, 2, 3],
		'items': {}
	},
	'minecraft:dolphin': {
		'default': [2, 3, 4],
		'items': {}
	},
	'minecraft:panda': {
		'default': [2, 2, 3],
		'items': {}
	},
	'minecraft:panda': {
		'default': [4, 7, 10],
		'items': {}
	},
	'minecraft:silverfish': {
		'default': [1, 1, 1],
		'items': {}
	},
	'minecraft:skeleton': {
		'default': [2, 2, 3],
		'items': {
			'minecraft:bow': ['1-4', '1-4', '1-5'],
			'minecraft:wooden_sword': [4, 6, 9],
			'minecraft:golden_sword': [4, 6, 9],
			'minecraft:stone_sword': [5, 7, 10],
			'minecraft:iron_sword': [5, 8, 12],
			'minecraft:diamond_sword': [6, 9, 13],
			'minecraft:netherite_sword': [6, 10, 15],
			'minecraft:trident': [6, 10, 15],
			'minecraft:wooden_shovel': [2, 3, 4],
			'minecraft:golden_shovel': [2, 3, 4],
			'minecraft:stone_shovel': [3, 4, 6],
			'minecraft:iron_shovel': [3, 5, 7],
			'minecraft:diamond_shovel': [4, 6, 9],
			'minecraft:netherite_shovel': [4, 10, 15],
			'minecraft:wooden_pickaxe': [3, 4, 6],
			'minecraft:golden_pickaxe': [3, 4, 6],
			'minecraft:stone_pickaxe': [3, 5, 7],
			'minecraft:iron_pickaxe': [4, 6, 9],
			'minecraft:diamond_pickaxe': [4, 7, 10],
			'minecraft:netherite_pickaxe': [5, 8, 12],
			'minecraft:wooden_axe': [3, 5, 7],
			'minecraft:golden_axe': [3, 5, 7],
			'minecraft:stone_axe': [4, 6, 9],
			'minecraft:iron_axe': [4, 7, 10],
			'minecraft:diamond_axe': [5, 8, 12],
			'minecraft:netherite_axe': [5, 9, 13],
			'minecraft:wooden_hoe': [3, 4, 6],
			'minecraft:golden_hoe': [3, 4, 6],
			'minecraft:stone_hoe': [3, 5, 7],
			'minecraft:iron_hoe': [4, 6, 9],
			'minecraft:diamond_hoe': [4, 7, 10],
			'minecraft:netherite_hoe': [5, 8, 12]
		}
	},
	'minecraft:wither_skeleton': {
		'default': [3, 4, 6],
		'items': {
			'minecraft:trident': [7, 12, 17],
			'minecraft:wooden_sword': [5, 8, 11],
			'minecraft:golden_sword': [5, 8, 11],
			'minecraft:stone_sword': [5, 9, 12],
			'minecraft:iron_sword': [6, 10, 15],
			'minecraft:diamond_sword': [6, 10, 16],
			'minecraft:netherite_sword': [7, 12, 17],
			'minecraft:wooden_shovel': [3, 5, 7],
			'minecraft:golden_shovel': [3, 5, 7],
			'minecraft:stone_shovel': [4, 6, 9],
			'minecraft:iron_shovel': [4, 7, 10],
			'minecraft:diamond_shovel': [5, 8, 12],
			'minecraft:netherite_shovel': [5, 9, 13],
			'minecraft:wooden_pickaxe': [4, 6, 9],
			'minecraft:golden_pickaxe': [4, 6, 9],
			'minecraft:stone_pickaxe': [4, 7, 10],
			'minecraft:iron_pickaxe': [5, 8, 12],
			'minecraft:diamond_pickaxe': [5, 9, 13],
			'minecraft:netherite_pickaxe': [6, 10, 15],
			'minecraft:wooden_axe': [4, 7, 10],
			'minecraft:golden_axe': [4, 7, 10],
			'minecraft:stone_axe': [5, 9, 13],
			'minecraft:iron_axe': [5, 9, 13],
			'minecraft:diamond_axe': [6, 10, 15],
			'minecraft:netherite_axe': [6, 11, 16],
			'minecraft:wooden_hoe': [4, 6, 9],
			'minecraft:golden_hoe': [4, 6, 9],
			'minecraft:stone_hoe': [3, 7, 10],
			'minecraft:iron_hoe': [5, 8, 12],
			'minecraft:diamond_hoe': [5, 9, 13],
			'minecraft:netherite_hoe': [6, 10, 15]
		}

	},
	'minecraft:stray': {
		'default': [2, 2, 3],
		'items': {
			'minecraft:bow': ['1-4', '1-4', '1-5'],
			'minecraft:wooden_sword': [4, 6, 9],
			'minecraft:golden_sword': [4, 6, 9],
			'minecraft:stone_sword': [5, 7, 10],
			'minecraft:iron_sword': [5, 8, 12],
			'minecraft:diamond_sword': [6, 9, 13],
			'minecraft:netherite_sword': [6, 10, 15],
			'minecraft:trident': [6, 10, 15],
			'minecraft:wooden_shovel': [2, 3, 4],
			'minecraft:golden_shovel': [2, 3, 4],
			'minecraft:stone_shovel': [3, 4, 6],
			'minecraft:iron_shovel': [3, 5, 7],
			'minecraft:diamond_shovel': [4, 6, 9],
			'minecraft:netherite_shovel': [4, 10, 15],
			'minecraft:wooden_pickaxe': [3, 4, 6],
			'minecraft:golden_pickaxe': [3, 4, 6],
			'minecraft:stone_pickaxe': [3, 5, 7],
			'minecraft:iron_pickaxe': [4, 6, 9],
			'minecraft:diamond_pickaxe': [4, 7, 10],
			'minecraft:netherite_pickaxe': [5, 8, 12],
			'minecraft:wooden_axe': [3, 5, 7],
			'minecraft:golden_axe': [3, 5, 7],
			'minecraft:stone_axe': [4, 6, 9],
			'minecraft:iron_axe': [4, 7, 10],
			'minecraft:diamond_axe': [5, 8, 12],
			'minecraft:netherite_axe': [5, 9, 13],
			'minecraft:wooden_hoe': [3, 4, 6],
			'minecraft:golden_hoe': [3, 4, 6],
			'minecraft:stone_hoe': [3, 5, 7],
			'minecraft:iron_hoe': [4, 6, 9],
			'minecraft:diamond_hoe': [4, 7, 10],
			'minecraft:netherite_hoe': [5, 8, 12]
		}
	},
	'minecraft:slime_big': {
		'default': [3, 4, 6],
		'items': {}
	},
	'minecraft:slime_normal': {
		'default': [3, 4, 6],
		'items': {}
	},
	'minecraft:zombie': {
		'default': [2, 3, 4],
		'items': {
			'minecraft:trident': [6, 11, 16],
			'minecraft:wooden_sword': [4, 7, 10],
			'minecraft:golden_sword': [4, 7, 10],
			'minecraft:stone_sword': [5, 8, 12],
			'minecraft:iron_sword': [5, 9, 13],
			'minecraft:diamond_sword': [6, 10, 15],
			'minecraft:netherite_sword': [6, 11, 16],
			'minecraft:wooden_shovel': [3, 4, 6],
			'minecraft:golden_shovel': [3, 4, 6],
			'minecraft:stone_shovel': [3, 5, 7],
			'minecraft:iron_shovel': [4, 6, 9],
			'minecraft:diamond_shovel': [4, 7, 10],
			'minecraft:netherite_shovel': [5, 8, 12],
			'minecraft:wooden_pickaxe': [3, 5, 7],
			'minecraft:golden_pickaxe': [3, 5, 7],
			'minecraft:stone_pickaxe': [4, 6, 9],
			'minecraft:iron_pickaxe': [4, 7, 10],
			'minecraft:diamond_pickaxe': [5, 8, 12],
			'minecraft:netherite_pickaxe': [5, 9, 13],
			'minecraft:wooden_axe': [4, 6, 9],
			'minecraft:golden_axe': [4, 6, 9],
			'minecraft:stone_axe': [4, 7, 10],
			'minecraft:iron_axe': [5, 8, 12],
			'minecraft:diamond_axe': [5, 9, 13],
			'minecraft:netherite_axe': [6, 10, 15],
			'minecraft:wooden_hoe': [3, 5, 7],
			'minecraft:golden_hoe': [3, 5, 7],
			'minecraft:stone_hoe': [4, 6, 9],
			'minecraft:iron_hoe': [4, 7, 10],
			'minecraft:diamond_hoe': [5, 8, 12],
			'minecraft:netherite_hoe': [5, 9, 13]
		}
	},
	'minecraft:husk': {
		'default': [2, 3, 4],
		'items': {
			'minecraft:trident': [6, 11, 16],
			'minecraft:wooden_sword': [4, 7, 10],
			'minecraft:golden_sword': [4, 7, 10],
			'minecraft:stone_sword': [5, 8, 12],
			'minecraft:iron_sword': [5, 9, 13],
			'minecraft:diamond_sword': [6, 10, 15],
			'minecraft:netherite_sword': [6, 11, 16],
			'minecraft:wooden_shovel': [3, 4, 6],
			'minecraft:golden_shovel': [3, 4, 6],
			'minecraft:stone_shovel': [3, 5, 7],
			'minecraft:iron_shovel': [4, 6, 9],
			'minecraft:diamond_shovel': [4, 7, 10],
			'minecraft:netherite_shovel': [5, 8, 12],
			'minecraft:wooden_pickaxe': [3, 5, 7],
			'minecraft:golden_pickaxe': [3, 5, 7],
			'minecraft:stone_pickaxe': [4, 6, 9],
			'minecraft:iron_pickaxe': [4, 7, 10],
			'minecraft:diamond_pickaxe': [5, 8, 12],
			'minecraft:netherite_pickaxe': [5, 9, 13],
			'minecraft:wooden_axe': [4, 6, 9],
			'minecraft:golden_axe': [4, 6, 9],
			'minecraft:stone_axe': [4, 7, 10],
			'minecraft:iron_axe': [5, 8, 12],
			'minecraft:diamond_axe': [5, 9, 13],
			'minecraft:netherite_axe': [6, 10, 15],
			'minecraft:wooden_hoe': [3, 5, 7],
			'minecraft:golden_hoe': [3, 5, 7],
			'minecraft:stone_hoe': [4, 6, 9],
			'minecraft:iron_hoe': [4, 7, 10],
			'minecraft:diamond_hoe': [5, 8, 12],
			'minecraft:netherite_hoe': [5, 9, 13]
		}
	},
	'minecraft:drowned': {
		'default': [2, 3, 4],
		'items': {
			'minecraft:trident': [6, 11, 16],
			'minecraft:wooden_sword': [4, 7, 10],
			'minecraft:golden_sword': [4, 7, 10],
			'minecraft:stone_sword': [5, 8, 12],
			'minecraft:iron_sword': [5, 9, 13],
			'minecraft:diamond_sword': [6, 10, 15],
			'minecraft:netherite_sword': [6, 11, 16],
			'minecraft:wooden_shovel': [3, 4, 6],
			'minecraft:golden_shovel': [3, 4, 6],
			'minecraft:stone_shovel': [3, 5, 7],
			'minecraft:iron_shovel': [4, 6, 9],
			'minecraft:diamond_shovel': [4, 7, 10],
			'minecraft:netherite_shovel': [5, 8, 12],
			'minecraft:wooden_pickaxe': [3, 5, 7],
			'minecraft:golden_pickaxe': [3, 5, 7],
			'minecraft:stone_pickaxe': [4, 6, 9],
			'minecraft:iron_pickaxe': [4, 7, 10],
			'minecraft:diamond_pickaxe': [5, 8, 12],
			'minecraft:netherite_pickaxe': [5, 9, 13],
			'minecraft:wooden_axe': [4, 6, 9],
			'minecraft:golden_axe': [4, 6, 9],
			'minecraft:stone_axe': [4, 7, 10],
			'minecraft:iron_axe': [5, 8, 12],
			'minecraft:diamond_axe': [5, 9, 13],
			'minecraft:netherite_axe': [6, 10, 15],
			'minecraft:wooden_hoe': [3, 5, 7],
			'minecraft:golden_hoe': [3, 5, 7],
			'minecraft:stone_hoe': [4, 6, 9],
			'minecraft:iron_hoe': [4, 7, 10],
			'minecraft:diamond_hoe': [5, 8, 12],
			'minecraft:netherite_hoe': [5, 9, 13]
		}
	},
	'minecraft:zombie_pigman': {
		'default': [3, 5, 7],
		'items': {
			'minecraft:trident': [7, 13, 19],
			'minecraft:wooden_sword': [5, 9, 13],
			'minecraft:golden_sword': [5, 9, 13],
			'minecraft:stone_sword': [6, 10, 15],
			'minecraft:iron_sword': [6, 11, 16],
			'minecraft:diamond_sword': [7, 12, 18],
			'minecraft:netherite_sword': [7, 13, 19],
			'minecraft:wooden_shovel': [4, 6, 9],
			'minecraft:golden_shovel': [4, 6, 9],
			'minecraft:stone_shovel': [4, 7, 10],
			'minecraft:iron_shovel': [5, 8, 12],
			'minecraft:diamond_shovel': [5, 9, 13],
			'minecraft:netherite_shovel': [6, 10, 15],
			'minecraft:wooden_pickaxe': [4, 7, 10],
			'minecraft:golden_pickaxe': [4, 7, 10],
			'minecraft:stone_pickaxe': [5, 8, 12],
			'minecraft:iron_pickaxe': [5, 9, 13],
			'minecraft:diamond_pickaxe': [6, 10, 15],
			'minecraft:netherite_pickaxe': [6, 11, 16],
			'minecraft:wooden_axe': [5, 8, 12],
			'minecraft:golden_axe': [5, 8, 12],
			'minecraft:stone_axe': [5, 9, 13],
			'minecraft:iron_axe': [6, 10, 15],
			'minecraft:diamond_axe': [6, 11, 16],
			'minecraft:netherite_axe': [7, 12, 18],
			'minecraft:wooden_hoe': [4, 7, 10],
			'minecraft:golden_hoe': [4, 7, 10],
			'minecraft:stone_hoe': [5, 8, 12],
			'minecraft:iron_hoe': [5, 9, 13],
			'minecraft:diamond_hoe': [6, 10, 15],
			'minecraft:netherite_hoe': [6, 11, 16]
		}
	},
	'minecraft:cave_spider': {
		'default': [2, 2, 3],
		'items': {}
	},
	'minecraft:spider': {
		'default': [2, 2, 3],
		'items': {}
	},
	'minecraft:elder_guardian_range': {
		'default': [5, 8, 12],
		'items': {}
	},
	'minecraft:elder_guardian': {
		'default': [2, 2, 3],
		'items': {}
	},
	'minecraft:guardian': {
		'default': [2, 2, 3],
		'items': {}
	},
	'minecraft:guardian_range': {
		'default': [4, 6, 9],
		'items': {}
	},
	'minecraft:ender_mite': {
		'default': [2, 2, 3],
		'items': {}
	},
	'minecraft:magma_cube_big': {
		'default': [4, 6, 9],
		'items': {}
	},
	'minecraft:magma_cube_medium': {
		'default': [3, 4, 6],
		'items': {}
	},
	'minecraft:magma_cube_small': {
		'default': [2, 3, 4],
		'items': {}
	},
	'minecraft:hoglin': {
		'default': ['3-10', '3-10', '3-10'],
		'items': {}
	},
	'minecraft:piglin': {
		'default': [3, 5, 7],
		'items': {
			'minecraft:trident': [7, 13, 19],
			'minecraft:crossbow': ['1-4', '1-4', '1-5'],
			'minecraft:wooden_sword': [5, 9, 13],
			'minecraft:golden_sword': [5, 9, 13],
			'minecraft:stone_sword': [6, 10, 15],
			'minecraft:iron_sword': [6, 11, 16],
			'minecraft:diamond_sword': [7, 12, 18],
			'minecraft:netherite_sword': [7, 13, 19],
			'minecraft:wooden_shovel': [4, 6, 9],
			'minecraft:golden_shovel': [4, 6, 9],
			'minecraft:stone_shovel': [4, 7, 10],
			'minecraft:iron_shovel': [5, 8, 12],
			'minecraft:diamond_shovel': [5, 9, 13],
			'minecraft:netherite_shovel': [6, 10, 15],
			'minecraft:wooden_pickaxe': [4, 7, 10],
			'minecraft:golden_pickaxe': [4, 7, 10],
			'minecraft:stone_pickaxe': [5, 8, 12],
			'minecraft:iron_pickaxe': [5, 9, 13],
			'minecraft:diamond_pickaxe': [6, 10, 15],
			'minecraft:netherite_pickaxe': [6, 11, 16],
			'minecraft:wooden_axe': [5, 8, 12],
			'minecraft:golden_axe': [5, 8, 12],
			'minecraft:stone_axe': [5, 9, 13],
			'minecraft:iron_axe': [6, 10, 15],
			'minecraft:diamond_axe': [6, 11, 16],
			'minecraft:netherite_axe': [7, 12, 18],
			'minecraft:wooden_hoe': [4, 7, 10],
			'minecraft:golden_hoe': [4, 7, 10],
			'minecraft:stone_hoe': [5, 8, 12],
			'minecraft:iron_hoe': [5, 9, 13],
			'minecraft:diamond_hoe': [6, 10, 15],
			'minecraft:netherite_hoe': [6, 11, 16]
		}
	},
	'minecraft:zoglin': {
		'default': ['3-10', '3-10', '3-10'],
		'items': {}
	},
	'minecraft:piglin_brute': {
		'default': [4, 7, 10],
		'items': {
			'minecraft:trident': [8, 12, 22],
			'minecraft:wooden_sword': [6, 11, 16],
			'minecraft:golden_sword': [6, 11, 16],
			'minecraft:stone_sword': [7, 12, 18],
			'minecraft:iron_sword': [7, 13, 19],
			'minecraft:diamond_sword': [8, 14, 21],
			'minecraft:netherite_sword': [8, 12, 22],
			'minecraft:wooden_shovel': [5, 8, 12],
			'minecraft:golden_shovel': [5, 8, 12],
			'minecraft:stone_shovel': [5, 9, 13],
			'minecraft:iron_shovel': [6, 10, 15],
			'minecraft:diamond_shovel': [6, 11, 16],
			'minecraft:netherite_shovel': [7, 12, 18],
			'minecraft:wooden_pickaxe': [5, 9, 13],
			'minecraft:golden_pickaxe': [5, 9, 13],
			'minecraft:stone_pickaxe': [6, 10, 15],
			'minecraft:iron_pickaxe': [6, 11, 16],
			'minecraft:diamond_pickaxe': [7, 12, 18],
			'minecraft:netherite_pickaxe': [7, 13, 19],
			'minecraft:wooden_axe': [6, 10, 15],
			'minecraft:golden_axe': [6, 10, 15],
			'minecraft:stone_axe': [6, 11, 16],
			'minecraft:iron_axe': [7, 12, 18],
			'minecraft:diamond_axe': [7, 13, 19],
			'minecraft:netherite_axe': [8, 14, 21],
			'minecraft:wooden_hoe': [5, 9, 13],
			'minecraft:golden_hoe': [5, 9, 13],
			'minecraft:stone_hoe': [6, 10, 15],
			'minecraft:iron_hoe': [6, 11, 16],
			'minecraft:diamond_hoe': [7, 12, 18],
			'minecraft:netherite_hoe': [7, 13, 19]
		}
	},
	'minecraft:warden': {
		'default': [16, 30, 45],
		'items': {}
	},
	'minecraft:warden_range': {
		'default': [6, 10, 15],
		'items': {}
	},
	'minecraft:ghast': {
		'default': [7, 12, 22],
		'items': {}
	},
	'minecraft:blaze': {
		'default': [4, 6, 9],
		'items': {}
	},
	'minecraft:blaze_range': {
		'default': [9, 9, 9],
		'items': {}
	},
	'minecraft:shulker': {
		'default': [4, 4, 4],
		'items': {}
	},
	'minecraft:vindicator': {
		'default': [5, 8, 12],
		'items': {
			'minecraft:trident': [9, 16, 24],
			'minecraft:wooden_sword': [7, 12, 18],
			'minecraft:golden_sword': [7, 12, 18],
			'minecraft:stone_sword': [7, 13, 19],
			'minecraft:iron_sword': [8, 14, 21],
			'minecraft:diamond_sword': [8, 15, 22],
			'minecraft:netherite_sword': [9, 16, 24],
			'minecraft:wooden_shovel': [5, 9, 13],
			'minecraft:golden_shovel': [5, 9, 13],
			'minecraft:stone_shovel': [6, 10, 15],
			'minecraft:iron_shovel': [6, 11, 16],
			'minecraft:diamond_shovel': [7, 12, 18],
			'minecraft:netherite_shovel': [7, 13, 19],
			'minecraft:wooden_pickaxe': [6, 10, 15],
			'minecraft:golden_pickaxe': [6, 10, 15],
			'minecraft:stone_pickaxe': [6, 11, 16],
			'minecraft:iron_pickaxe': [7, 12, 18],
			'minecraft:diamond_pickaxe': [7, 13, 19],
			'minecraft:netherite_pickaxe': [8, 14, 21],
			'minecraft:wooden_axe': [6, 11, 16],
			'minecraft:golden_axe': [6, 11, 16],
			'minecraft:stone_axe': [7, 12, 18],
			'minecraft:iron_axe': [7, 13, 19],
			'minecraft:diamond_axe': [8, 14, 21],
			'minecraft:netherite_axe': [8, 15, 22],
			'minecraft:wooden_hoe': [6, 10, 15],
			'minecraft:golden_hoe': [6, 10, 15],
			'minecraft:stone_hoe': [6, 11, 16],
			'minecraft:iron_hoe': [7, 12, 18],
			'minecraft:diamond_hoe': [7, 13, 19],
			'minecraft:netherite_hoe': [8, 14, 21]
		}
	},
	'minecraft:evocation_illager': {
		'default': [6, 6, 6],
		'items': {}
	},
	'minecraft:vex': {
		'default': [5, 9, 13],
		'items': {}
	},
	'minecraft:zombie_villager_v2': {
		'default': [2, 3, 4],
		'items': {
			'minecraft:trident': [6, 11, 16],
			'minecraft:wooden_sword': [4, 7, 10],
			'minecraft:golden_sword': [4, 7, 10],
			'minecraft:stone_sword': [5, 8, 12],
			'minecraft:iron_sword': [5, 9, 13],
			'minecraft:diamond_sword': [6, 10, 15],
			'minecraft:netherite_sword': [6, 11, 16],
			'minecraft:wooden_shovel': [3, 4, 6],
			'minecraft:golden_shovel': [3, 4, 6],
			'minecraft:stone_shovel': [3, 5, 7],
			'minecraft:iron_shovel': [4, 6, 9],
			'minecraft:diamond_shovel': [4, 7, 10],
			'minecraft:netherite_shovel': [5, 8, 12],
			'minecraft:wooden_pickaxe': [3, 5, 7],
			'minecraft:golden_pickaxe': [3, 5, 7],
			'minecraft:stone_pickaxe': [4, 6, 9],
			'minecraft:iron_pickaxe': [4, 7, 10],
			'minecraft:diamond_pickaxe': [5, 8, 12],
			'minecraft:netherite_pickaxe': [5, 9, 13],
			'minecraft:wooden_axe': [4, 6, 9],
			'minecraft:golden_axe': [4, 6, 9],
			'minecraft:stone_axe': [4, 7, 10],
			'minecraft:iron_axe': [5, 8, 12],
			'minecraft:diamond_axe': [5, 9, 13],
			'minecraft:netherite_axe': [6, 10, 15],
			'minecraft:wooden_hoe': [3, 5, 7],
			'minecraft:golden_hoe': [3, 5, 7],
			'minecraft:stone_hoe': [4, 6, 9],
			'minecraft:iron_hoe': [4, 7, 10],
			'minecraft:diamond_hoe': [5, 8, 12],
			'minecraft:netherite_hoe': [5, 9, 13]
		}
	},
	'minecraft:phantom': {
		'default': [4, 6, 9],
		'items': {}
	},
	'minecraft:pillager': {
		'default': ['1-4', '1-4', '1-5'],
		'items': {}
	},
	'minecraft:ravager': {
		'default': [7, 12, 18],
		'items': {}
	},
	'minecraft:ravager_range': {
		'default': [4, 6, 9],
		'items': {}
	},
	'minecraft:iron_golem': {
		'default': ['7-21', '7-21', '7-21'],
		'items': {}
	}
};

export default {
	deg360, getAngleXZ, angleDif, distXZ,
	addItem, addItemToSlot, getItem, setItem, lookForItem, clearItem,
	storeDataToEntity, appendDataToEntity, getDataFromEntity, removeDataFromEntity, getAllDataNamesFromEntity, entityHasData,
	getBlockPermutationValue, capFirstLetter,
    effects, armor, damage_list
}