import {
    MinecraftEffectTypes,
    Vector,
    world,
    system
} from '@minecraft/server';
import * as lib from 'class/lib.js';
const char = `ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789\`~!@#$%^&*()-_=+[{]};:'"\\|,<.>/? `;

world.events.itemStartCharge.subscribe(e => {
    if (!e.itemStack.typeId.endsWith('spyglass') || !e.source.typeId.endsWith('player')) return;
    e.source.active = true;
});
world.events.itemReleaseCharge.subscribe(e => {
    if (!e.itemStack.typeId.endsWith('spyglass') || !e.source.typeId.endsWith('player')) return;
    e.source.active = false;
});

world.events.entityDie.subscribe(e => {
    if (e.deadEntity.typeId == 'minecraft:player') {
        lib.storeDataToEntity(e.deadEntity, 'death_point', `{"x":${e.deadEntity.location.x},"y":${e.deadEntity.location.y},"z":${e.deadEntity.location.z}}`);
    }
});

world.events.playerSpawn.subscribe(e => {
    if (!lib.entityHasData(e.player, 'spawn_point')) {
        lib.storeDataToEntity(e.player, 'spawn_point', `{"x":${e.player.location.x},"y":${e.player.location.y},"z":${e.player.location.z}}`);
    }
});

let loop = system.runInterval(_ => { 
    try {
        for (let player of world.getPlayers()) {
            let str = '';

            if (player.active) {
                let location = null;

                let e = player.getEntitiesFromViewDirection({ maxDistance: 1000 })[0];
                let b = player.getBlockFromViewDirection({ maxDistance: 1000 });

                let item = lib.getItem(player);
                if (item && item.getLore()) {
                    if (item.getLore()[0] == 'night_vision') {
                        player.addEffect(MinecraftEffectTypes.nightVision, 5, 0, false);
                    }
                }

                let constant = null, name1 = null, name2 = null, data = null
                for (let ent of player.dimension.getEntities({ tags: [`${player.id}`] })) {
                    if (ent.typeId == 'super:constant') constant = ent;
                    else if (ent.typeId == 'super:name') name1 = ent;
                    else if (ent.typeId == 'super:name2') name2 = ent;
                    else if (ent.typeId == 'super:data') data = ent;
                };

                if (e && !e.typeId.startsWith('super')) {
                    location = e.location;
                    if (player.current != e.id) {
                        for (let e of player.dimension.getEntities({ tags: [`${player.id}`] })) {
                            e.triggerEvent('super:reset');
                        };
                        player.current = e.id;
                    }

                    let name = e.typeId.split(':').pop().replace('_v2', '').replaceAll('_', ' ');
                    let nameTag = e.nameTag, scale = '';
                    if (e.getComponent('scale')) scale = ' x' + (Math.floor(e.getComponent('scale').value * 10) / 10);
                    if (e.getComponent('is_baby')) name = `baby ${name}`;

                    if (e.typeId == 'minecraft:item') {
                        let item = e.getComponent('item');
                        if (item) {
                            nameTag = lib.capFirstLetter(item.itemStack.typeId.split(':')[item.itemStack.typeId.split(':').length - 1].replace('_v2', '').replaceAll('_', ' '));
                            scale = ' x' + item.itemStack.amount;
                        }
                    }
                    let newName = `${nameTag} [${lib.capFirstLetter(name)}]${scale}`;
                    if (nameTag == '') newName = `${lib.capFirstLetter(name)}${scale}`;
                    if (e.typeId == 'minecraft:creeper' && e.hasComponent('is_charged')) newName = `Charged Creeper${scale}`;

                    if (!name1) {
                        name1 = player.dimension.spawnEntity('super:name', player.location);
                        name1.addTag(`${player.id}`);
                    }
                    if (!name2) {
                        name2 = player.dimension.spawnEntity('super:name2', player.location);
                        name2.addTag(`${player.id}`);
                    }
                    if (!data) {
                        data = player.dimension.spawnEntity('super:data', player.location);
                        data.addTag(`${player.id}`);
                    }

                    if (name1 && name2 && data) {
                        for (let i = 0; i < newName.length; i++) {
                            let index = (char.indexOf(newName[i]) == -1) ? 95 : char.indexOf(newName[i]);
                            if (i >= 31) name2.triggerEvent(`super:name2_${i - 31}_${index}`);
                            else name1.triggerEvent(`super:name_${i}_${char.indexOf(newName[i])}`);
                        }

                        lib.effects.forEach(a => {
                            for (let et in MinecraftEffectTypes) {
                                if (MinecraftEffectTypes[et].getName() != a) continue;
                                data.triggerEvent(`super:${a}_${(e.getEffect(MinecraftEffectTypes[et]) ? 1 : 0)}`);
                            }
                        });

                        if (e.typeId.endsWith('player')) {
                            name1.getComponent('minecraft:mark_variant').value = e.xpEarnedAtCurrentLevel;
                            name1.getComponent('minecraft:skin_id').value = e.totalXpNeededForNextLevel;
                        }
                        if (e.hasComponent('color')) data.triggerEvent(`super:color_${e.getComponent('color').value}`);
                    }
                } else if (b) {
                    location = b.location;
                    for (let e of player.dimension.getEntities({ tags: [`${player.id}`] })) {
                        if (e.typeId.endsWith('data')) e.triggerEvent('super:despawn');
                        else e.triggerEvent('super:reset');
                    };
                    player.current = null;
                    let newName = `${b.typeId.split(':').pop().replace(/[0-9]/g, '').replaceAll('_', ' ')} [Block]`;
                    for (let t of ['wood_type', 'old_log_type', 'old_leaf_type', 'new_log_type', 'new_leaf_type', 'color']) {
                        if (!lib.getBlockPermutationValue(b, t)) continue;
                        newName = `${lib.getBlockPermutationValue(b, t)} ${newName}`;
                    }
                    if (b.typeId == 'minecraft:stone' && lib.getBlockPermutationValue(b, 'stone_type'))
                        newName = `${lib.getBlockPermutationValue(b, 'stone_type').replaceAll('_', ' ')} [Block]`;
                    if (b.getRedstonePower()) newName += ` [${b.getRedstonePower()}]`;
                    newName = lib.capFirstLetter(newName);

                    if (!name1) {
                        name1 = player.dimension.spawnEntity('super:name', player.location);
                        name1.addTag(`${player.id}`);
                    }
                    if (!name2) {
                        name2 = player.dimension.spawnEntity('super:name2', player.location);
                        name2.addTag(`${player.id}`);
                    }

                    if (name1 && name2) {
                        for (let i = 0; i < newName.length; i++) {
                            let index = (char.indexOf(newName[i]) == -1) ? 95 : char.indexOf(newName[i]);
                            if (i >= 31) name2.triggerEvent(`super:name2_${i - 31}_${index}`);
                            else name1.triggerEvent(`super:name_${i}_${char.indexOf(newName[i])}`);
                        }
                    }
                } else {
                    for (let e of player.dimension.getEntities({ tags: [`${player.id}`] })) {
                        if (e.typeId.endsWith('data')) e.triggerEvent('super:despawn');
                        if (e.typeId.endsWith('name')) e.triggerEvent('super:despawn');
                        else e.triggerEvent('super:reset');
                    };
                }

                if (!constant) {
                    constant = player.dimension.spawnEntity('super:constant', player.location);
                    constant.addTag(`${player.id}`);
                }
                if (!name2) {
                    name2 = player.dimension.spawnEntity('super:name2', player.location);
                    name2.addTag(`${player.id}`);
                }

                if (constant && name2) {
                    player.angleFacing = lib.deg360(player.getRotation().y);
                    constant.getComponent('health').setCurrent(player.angleFacing * 1e4 + 1);
                    if (location) {
                        constant.getComponent('mark_variant').value = location.x * 1e4;
                        constant.triggerEvent(`super:y_${Math.floor(location.y)}`);
                        constant.getComponent('skin_id').value = location.z * 1e4;
                        constant.triggerEvent('super:not_void');
                    } else constant.triggerEvent('super:void');

                    // Spawn Point
                    let sp = player.getSpawnPosition() || lib.getDataFromEntity(player, 'spawn_point');
                    if (sp) { 
                        let a = lib.deg360(lib.getAngleXZ(sp, player.location) + 90);
                        let ad = lib.angleDif(player.angleFacing, a);

                        name2.getComponent('mark_variant').value = Math.floor(Math.abs(ad) * 1000);
                        let d = Vector.distance(sp, player.location);
                        let mapped = d > 100 ? 0 : d >= 10 ? 1 : 2;
                        constant.triggerEvent(`super:spawn_dist_${mapped}${ad < 0 ? 0 : 1}`);
                    }
                    
                    // Death Point
                    let dp = lib.getDataFromEntity(player, 'death_point');
                    if (typeof dp === 'object' && dp !== null) {
                        let a = lib.deg360(lib.getAngleXZ(dp, player.location) + 90);
                        let ad = lib.angleDif(player.angleFacing, a);

                        name2.getComponent('skin_id').value = Math.floor(Math.abs(ad) * 1000);
                        let d = Vector.distance(dp, player.location);
                        let mapped = d > 100 ? 0 : d >= 10 ? 1 : 2;
                        constant.triggerEvent(`super:death_dist_${mapped}${ad < 0 ? 0 : 1}`);
                    }
                }
                if (constant) constant.teleport(player.location, player.dimension, 0, 0);
                if (name1) name1.teleport(player.location, player.dimension, 0, 0);
                if (name2) name2.teleport(player.location, player.dimension, 0, 0);
                if (data) data.teleport(player.location, player.dimension, 0, 0);
            } else {
                for (let e of player.dimension.getEntities({ tags: [`${player.id}`] })) {
                    e.triggerEvent('super:despawn');
                }
            }
            player.onScreenDisplay.setActionBar(str);
        }
    } catch (err) {
        throw err;
        system.clearRun(loop);
    }
}, 1);
system.events.beforeWatchdogTerminate.subscribe(e => e.cancel = true);